==> py311-contourpy-1.2.0.tgz: lib/python3.11/site-packages/contourpy/util/_build_config.py <==
# _build_config.py.in is converted into _build_config.py during the meson build process.

from __future__ import annotations


def build_config() -> dict[str, str]:
    """
    Return a dictionary containing build configuration settings.

    All dictionary keys and values are strings, for example ``False`` is
    returned as ``"False"``.

        .. versionadded:: 1.1.0
    """
    return dict(
        # Python settings
        python_version="3.11",
        python_install_dir=r"/usr/local/lib/python3.11/site-packages/",
        python_path=r"/usr/pkg/bin/python3.11",

        # Package versions
        contourpy_version="1.2.0",
        meson_version="1.4.0",
        mesonpy_version="0.15.0",
        pybind11_version="2.11.1",

        # Misc meson settings
        meson_backend="ninja",
        build_dir=r"/usr/pkgsrc/graphics/py-contourpy/work/contourpy-1.2.0/.mesonpy-sfajir1n/lib/contourpy/util",
        source_dir=r"/usr/pkgsrc/graphics/py-contourpy/work/contourpy-1.2.0/lib/contourpy/util",
        cross_build="False",

        # Build options
        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/usr/pkgsrc/graphics/py-contourpy/work/contourpy-1.2.0/.mesonpy-sfajir1n/meson-python-native-file.ini",
        buildtype="release",
        cpp_std="c++17",
        debug="False",
        optimization="3",
        vsenv="True",
        b_ndebug="if-release",
        b_vscrt="from_buildtype",

        # C++ compiler
        compiler_name="gcc",
        compiler_version="10.5.0",
        linker_id="ld.bfd",
        compile_command="c++",

        # Host machine
        host_cpu="powerpc",
        host_cpu_family="ppc",
        host_cpu_endian="big",
        host_cpu_system="netbsd",

        # Build machine, same as host machine if not a cross_build
        build_cpu="powerpc",
        build_cpu_family="ppc",
        build_cpu_endian="big",
        build_cpu_system="netbsd",
    )

==> py311-contourpy-1.3.0.tgz: lib/python3.11/site-packages/contourpy/util/_build_config.py <==
# _build_config.py.in is converted into _build_config.py during the meson build process.

from __future__ import annotations


def build_config() -> dict[str, str]:
    """
    Return a dictionary containing build configuration settings.

    All dictionary keys and values are strings, for example ``False`` is
    returned as ``"False"``.

        .. versionadded:: 1.1.0
    """
    return dict(
        # Python settings
        python_version="3.11",
        python_install_dir=r"/usr/local/lib/python3.11/site-packages/",
        python_path=r"/usr/pkg/bin/python3.11",

        # Package versions
        contourpy_version="1.3.0",
        meson_version="1.5.2",
        mesonpy_version="0.16.0",
        pybind11_version="2.13.6",

        # Misc meson settings
        meson_backend="ninja",
        build_dir=r"/tmp/pkgbuild/graphics/py-contourpy/work.sparc64/contourpy-1.3.0/.mesonpy-q79mn6ob/lib/contourpy/util",
        source_dir=r"/tmp/pkgbuild/graphics/py-contourpy/work.sparc64/contourpy-1.3.0/lib/contourpy/util",
        cross_build="False",

        # Build options
        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/tmp/pkgbuild/graphics/py-contourpy/work.sparc64/contourpy-1.3.0/.mesonpy-q79mn6ob/meson-python-native-file.ini",
        buildtype="release",
        cpp_std="c++17",
        debug="False",
        optimization="3",
        vsenv="True",
        b_ndebug="if-release",
        b_vscrt="from_buildtype",

        # C++ compiler
        compiler_name="gcc",
        compiler_version="7.5.0",
        linker_id="ld.bfd",
        compile_command="c++",

        # Host machine
        host_cpu="sparc64",
        host_cpu_family="sparc64",
        host_cpu_endian="big",
        host_cpu_system="netbsd",

        # Build machine, same as host machine if not a cross_build
        build_cpu="sparc64",
        build_cpu_family="sparc64",
        build_cpu_endian="big",
        build_cpu_system="netbsd",
    )
